NAME

qmail-deliverabled - Deliverability check daemon

USAGE

qmail-deliverabled [--listen 127.0.0.1:8998] [--pidfile /foo/bar.pid]
qmail-deliverabled --stop --pidfile /foo/bar.pid

--stop          Kill the process in the given --pidfile
--listen        IP and port to listen on, defaults to 127.0.0.1:8998
--foreground    Don't daemonize, but stay in the foreground
--verbose       Print debug information while running
--help          Print usage information and exit.
--pidfile       Write a pidfile (unless --stop is also given)

DESCRIPTION

Exposes the Qmail::Deliverable functions qmail_local and deliverable over HTTP. Typically requires root access for file permissions.

Use only with a ::Client of the same version. Returns 403 FORBIDDEN on error, any error.

A simple init.d-style script is provided in the .tar.gz, in the init.d directory.

SIGNALS

SIGHUP

Re-read /var/qmail/control/locals, /var/qmail/control/virtualdomains, and /var/qmail/users/assign without restarting.

SIGTERM, SIGINT

Shut down cleanly. The pidfile (if any) is removed before exit.

CAVEATS

The PIDFILE is not used to avoid concurrent processes: it's perfectly fine to have multiple qmail-deliverableds running on different addresses or ports, but make sure each combination has its own PIDFILE.

Verbose mode is only useful when also running with --foreground; once daemonized, standard handles are redirected to /dev/null and verbose output is silently discarded.

LEGAL

This software does not come with warranty or guarantee of any kind. Use it at your own risk.

This software may be redistributed under the terms of the GPL, LGPL, modified BSD, or Artistic license, or any of the other OSI approved licenses listed at http://www.opensource.org/licenses/alphabetical. Distribution is allowed under all of these these licenses, or any smaller subset of multiple or just one of these licenses.

When using a packaged version, please refer to the package metadata to see under which license terms it was distributed. Alternatively, a distributor may choose to replace the LICENSE section of the documentation and/or include a LICENSE file to reflect the license(s) they chose to redistribute under.

AUTHORS

  • Juerd Waalboer <#####@juerd.nl> (original author)

  • Matt Simerson <msimerson@cpan.org> (current maintainer)

CONTRIBUTORS

  • Martin Sluka

SEE ALSO

Qmail::Deliverable::Client